@@ -1,7 +1,7 @@
 # Author: David Goodger
 # Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 3358 $
-# Date: $Date: 2005-05-21 02:00:25 +0200 (Sat, 21 May 2005) $
+# Revision: $Revision: 4183 $
+# Date: $Date: 2005-12-12 05:12:02 +0100 (Mon, 12 Dec 2005) $
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -32,13 +32,16 @@ import os
 import os.path
 import sys
 import types
-import copy
 import warnings
 import ConfigParser as CP
 import codecs
 import docutils
-import optparse
-from optparse import SUPPRESS_HELP
+try:
+    import optparse
+    from optparse import SUPPRESS_HELP
+except ImportError:
+    import optik as optparse
+    from optik import SUPPRESS_HELP
 
 
 def store_multiple(option, opt, value, parser, *args, **kwargs):
@@ -216,6 +219,10 @@ class Values(optparse.Values):
                     del other_dict[setting]
         self._update_loose(other_dict)
 
+    def copy(self):
+        """Return a shallow copy of `self`."""
+        return self.__class__(defaults=self.__dict__)
+
 
 class Option(optparse.Option):
 
@@ -282,7 +289,10 @@ class OptionParser(optparse.OptionParser, docutils.SettingsSpec):
     settings_spec = (
         'General Docutils Options',
         None,
-        (('Include a "Generated by Docutils" credit and link at the end '
+        (('Specify the document title as metadata (not part of the document '
+          'body).  Overrides a document-provided title.  There is no default.',
+          ['--title'], {}),
+         ('Include a "Generated by Docutils" credit and link at the end '
           'of the document.',
           ['--generator', '-g'], {'action': 'store_true',
                                   'validator': validate_boolean}),
@@ -328,10 +338,23 @@ class OptionParser(optparse.OptionParser, docutils.SettingsSpec):
          ('Disable backlinks from footnotes and citations.',
           ['--no-footnote-backlinks'],
           {'dest': 'footnote_backlinks', 'action': 'store_false'}),
-         ('Disable Docutils section numbering',
+         ('Enable Docutils section numbering (default: enabled).',
+          ['--section-numbering'],
+          {'action': 'store_true', 'dest': 'sectnum_xform',
+           'default': 1, 'validator': validate_boolean}),
+         ('Disable Docutils section numbering (default: enabled).',
           ['--no-section-numbering'],
           {'action': 'store_false', 'dest': 'sectnum_xform',
-           'default': 1, 'validator': validate_boolean}),
+           'validator': validate_boolean}),
+         ('Remove comment elements from the document tree '
+          '(default: leave them).',
+          ['--strip-comments'],
+          {'action': 'store_true', 'validator': validate_boolean}),
+         ('Leave comment elements in the document tree '
+          '(this is the default).',
+          ['--leave-comments'],
+          {'action': 'store_false', 'dest': 'strip_comments',
+           'validator': validate_boolean}),
          ('Set verbosity threshold; report system messages at or higher than '
           '<level> (by name or number: "info" or "1", warning/2, error/3, '
           'severe/4; also, "none" or "5").  Default is 2 (warning).',
@@ -455,14 +478,15 @@ class OptionParser(optparse.OptionParser, docutils.SettingsSpec):
 
     settings_defaults = {'_disable_config': None,
                          '_source': None,
-                         '_destination': None}
+                         '_destination': None,}
     """Defaults for settings that don't have command-line option equivalents."""
 
     relative_path_settings = ('warning_stream',)
 
     config_section = 'general'
 
-    version_template = '%%prog (Docutils %s)' % docutils.__version__
+    version_template = ('%%prog (Docutils %s [%s])'
+                        % (docutils.__version__, docutils.__version_details__))
     """Default version message."""
 
     def __init__(self, components=(), defaults=None, read_config_files=None,
