@@ -13,7 +13,7 @@
 ##############################################################################
 """Select Widget Tests
 
-$Id: test_itemswidget.py 37977 2005-08-17 01:02:10Z poster $
+$Id: test_itemswidget.py 71639 2006-12-20 23:55:22Z jacobholm $
 """
 import sets
 import unittest
@@ -99,6 +99,12 @@ class ItemsWidgetBaseTest(VerifyResults, PlacelessSetup, unittest.TestCase):
         self.assertEqual(widget.name, 'foo.%s' %name)
         self.assertEqual(widget.empty_marker_name,
                          'foo.%s-empty-marker' %name)
+        # Declaring empty prefix
+        widget.setPrefix('')
+        self.assertEqual(widget._prefix, '')
+        self.assertEqual(widget.name, name)
+        self.assertEqual(widget.empty_marker_name,
+                         '%s-empty-marker' %name)
 
     def test_convertTokensToValues(self):
         widget = self._makeWidget()
@@ -137,13 +143,10 @@ class ItemsMultiDisplayWidgetTest(ItemsWidgetBaseTest):
         widget = self._makeWidget(form={'field.numbers': ['token1', 'token2']})
         self.assertEqual(
             widget(),
-            '<%s class="textType" '
-            'id="field.numbers" '
-            'name="field.numbers" '
-            'type="text" >'
+            '<%s id="field.numbers" >'
             '<li>One</li>\n<li>Two</li>'
             '</%s>' %(self._tag, self._tag))
-        
+
     def test_renderItems(self):
         widget = self._makeWidget()
         self.assertEqual(
@@ -301,8 +304,8 @@ class SelectWidgetTest(ItemsEditWidgetBaseTest):
         widget.setPrefix('field.')
         widget.firstItem = True
         self.assertEqual(
-            widget.renderItems(None),
-            [u'<option selected="selected" value="token1">One</option>',
+            widget.renderItems(widget._toFormValue(widget.context.missing_value)),
+            [u'<option value="token1">One</option>',
              u'<option value="token2">Two</option>',
              u'<option value="token3">Three</option>'])
 
@@ -381,8 +384,8 @@ class RadioWidgetTest(ItemsEditWidgetBaseTest):
 
     def test_renderItems_firstItem(self):
         widget = self._makeWidget()
-        widget.firstItem = True
-        items = widget.renderItems(None)
+        items = widget.renderItems(
+                widget._toFormValue(widget.context.missing_value))
         values = [('token1','One'), ('token2','Two'), ('token3','Three')]
         for index, item in enumerate(items):
             self.verifyResult(
@@ -390,7 +393,6 @@ class RadioWidgetTest(ItemsEditWidgetBaseTest):
                 ['<label', '<input', 'class="radioType"', 'name="field.choice"',
                  'id="field.choice.%i"' %index, 'type="radio"',
                  'value="%s"' %values[index][0], '&nbsp;%s' %values[index][1]])
-        self.verifyResult(items[0], ['checked="checked"'])
 
     def test_renderValue(self):
         widget = self._makeWidget()
@@ -415,6 +417,19 @@ class ItemsMultiEditWidgetBaseTest(ItemsEditWidgetBaseTest):
              '>One</option>\n', 'value="token2"', '>Two</option>\n',
              'value="token3"', '>Three</option>', '</select>'])
 
+    def test_renderItemsWithValues(self):
+        widget = self._makeWidget()
+        self.assertEqual(
+            widget.renderItemsWithValues(['one', 'two']),
+            [u'<option selected="selected" value="token1">One</option>',
+             u'<option selected="selected" value="token2">Two</option>',
+             u'<option value="token3">Three</option>'])
+        self.assertEqual(
+            widget.renderItemsWithValues([]),
+            [u'<option value="token1">One</option>',
+             u'<option value="token2">Two</option>',
+             u'<option value="token3">Three</option>'])
+
 # This test is disabled because it tests for the presense of a missfeature,
 # which has been removed.  Did someone actually *want* this?
 ##     def test_error(self):
