@@ -15,7 +15,7 @@
 
 BBB: ENTIRE PACKAGE IS DEPRECATED!!! 12/05/2004 Gone in 3.3
 
-$Id: __init__.py 39058 2005-10-11 18:31:25Z philikon $
+$Id: __init__.py 67630 2006-04-27 00:54:03Z jim $
 """
 __docformat__ = 'restructuredtext'
 
@@ -32,6 +32,8 @@ from BTrees.OIBTree import OIBTree
 from zope.interface import implements
 from zope.component.interfaces import IViewFactory
 from zope.deprecation import deprecated
+from zope.traversing.api import getPath
+from zope.location import locate
 
 from zope.app import zapi
 from zope.app.component import queryNextUtility
@@ -42,10 +44,8 @@ from zope.app.container.constraints import ItemTypePrecondition
 from zope.app.container.constraints import ContainerTypesConstraint
 from zope.app.container.contained import Contained, setitem, uncontained
 from zope.app.container.ordered import OrderedContainer
-from zope.app.location import locate
 from zope.app.security.interfaces import ILoginPassword, IAuthentication
 from zope.app.security.interfaces import PrincipalLookupError
-from zope.app.traversing.api import getPath
 
 from interfaces import IUserSchemafied, IPluggableAuthentication
 from interfaces import IPrincipalSource, ILoginPasswordPrincipalSource
@@ -203,7 +203,7 @@ def PluggableAuthenticationAddSubscriber(self, event):
 
     Define a stub for `PluggableAuthentication`
 
-    >>> from zope.app.traversing.interfaces import IPhysicallyLocatable
+    >>> from zope.traversing.interfaces import IPhysicallyLocatable
     >>> class PluggableAuthStub(object):
     ...     implements(IPhysicallyLocatable)
     ...     def __init__(self, earmark=None):
