@@ -13,7 +13,7 @@
 ##############################################################################
 """More convenience functions for dealing with proxies.
 
-$Id: __init__.py 25177 2004-06-02 13:17:31Z jim $
+$Id: __init__.py 67630 2006-04-27 00:54:03Z jim $
 """
 from zope.interface import moduleProvides
 from zope.proxy.interfaces import IProxyIntrospection
@@ -29,3 +29,6 @@ def ProxyIterator(p):
     while isProxy(p):
         p = getProxiedObject(p)
         yield p
+
+def non_overridable(func):
+    return property(lambda self: func.__get__(self))
