@@ -13,15 +13,16 @@
 ##############################################################################
 """Schema interfaces and exceptions
 
-$Id: interfaces.py 37565 2005-07-29 20:46:23Z srichter $
+$Id: interfaces.py 67630 2006-04-27 00:54:03Z jim $
 """
+__docformat__ = "reStructuredText"
 
 from zope.interface import Interface, Attribute
-from zope.schema._bootstrapfields import Field, Text, TextLine, Bool, Int
 from zope.schema._bootstrapfields import Container, Iterable
+from zope.schema._bootstrapfields import Field, Text, TextLine, Bool, Int
 
-from zope.i18nmessageid import MessageIDFactory
-_ = MessageIDFactory("zope")
+from zope.i18nmessageid import MessageFactory
+_ = MessageFactory("zope")
 
 # Import from _bootstrapinterfaces only because other packages will expect
 # to find these interfaces here.
@@ -136,7 +137,7 @@ class IField(Interface):
 
     order = Int(
         title=_(u"Field Order"),
-        description=_(u"""\
+        description=_(u"""
         The order attribute can be used to determine the order in
         which fields in a schema were defined. If one field is created
         after another (in the same thread), its order will be
@@ -184,23 +185,23 @@ class IIterable(IField):
     u"""Fields with a value that can be iterated over.
 
     The value needs to support iteration; the implementation mechanism
-    is not constrained.  (Either __iter__() or __getitem__() may be
+    is not constrained.  (Either `__iter__()` or `__getitem__()` may be
     used.)
     """
 
 class IContainer(IField):
-    u"""Fields whose value allows an 'x in value' check.
+    u"""Fields whose value allows an ``x in value`` check.
 
-    The Value needs to support the 'in' operator, but is not
-    constrained in how it does so (whether it defines __contains__()
-    or __getitem__() is immaterial).
+    The value needs to support the `in` operator, but is not
+    constrained in how it does so (whether it defines `__contains__()`
+    or `__getitem__()` is immaterial).
     """
 
 class IOrderable(IField):
     u"""Field requiring its value to be orderable.
 
     The set of value needs support a complete ordering; the
-    implementation mechanism is not constrained.  Either __cmp__() or
+    implementation mechanism is not constrained.  Either `__cmp__()` or
     'rich comparison' methods may be used.
     """
 
@@ -234,10 +235,10 @@ class IMinMaxLen(ILen):
 
     min_length = Int(
         title=_(u"Minimum length"),
-        description=_(u"""\
+        description=_(u"""
         Value after whitespace processing cannot have less than
-        min_length characters (if a string type) or elements (if
-        another sequence type). If min_length is None, there is
+        `min_length` characters (if a string type) or elements (if
+        another sequence type). If `min_length` is ``None``, there is
         no minimum.
         """),
         required=False,
@@ -246,11 +247,11 @@ class IMinMaxLen(ILen):
 
     max_length = Int(
         title=_(u"Maximum length"),
-        description=_(u"""\
+        description=_(u"""
         Value after whitespace processing cannot have greater
-        or equal than max_length characters (if a string type) or 
-        elements (if another sequence type). If max_length is
-        None, there is no maximum."""),
+        or equal than `max_length` characters (if a string type) or
+        elements (if another sequence type). If `max_length` is
+        ``None``, there is no maximum."""),
         required=False,
         min=0, # needs to be a positive number
         default=None)
@@ -395,6 +396,17 @@ class ISequence(ICollection):
 class IUnorderedCollection(ICollection):
     u"""Abstract interface specifying that the value cannot be ordered"""
 
+class IAbstractSet(IUnorderedCollection):
+    u"""An unordered collection of unique values."""
+    
+    unique = Attribute(u"This ICollection interface attribute must be True")
+
+class IAbstractBag(IUnorderedCollection):
+    u"""An unordered collection of values, with no limitations on whether
+    members are unique"""
+    
+    unique = Attribute(u"This ICollection interface attribute must be False")
+
 # Concrete
 
 class ITuple(ISequence):
@@ -405,11 +417,13 @@ class IList(ISequence):
     u"""Field containing a value that implements the API of a conventional 
     Python list."""
 
-class ISet(IUnorderedCollection):
+class ISet(IAbstractSet):
     u"""Field containing a value that implements the API of a conventional 
-    Python standard library sets.Set."""
-    
-    unique = Attribute(u"This ICollection interface attribute must be True")
+    Python standard library sets.Set or a Python 2.4+ set."""
+
+class IFrozenSet(IAbstractSet):
+    u"""Field containing a value that implements the API of a conventional 
+    Python 2.4+ frozenset."""
 
 # (end Collections)
 
@@ -498,11 +512,13 @@ class ISourceQueriables(Interface):
           searcing for items.
 
         """
+
+class IContextSourceBinder(Interface):
+    def __call__(context):
+        """Return a context-bound instance that implements ISource.
+        """
     
 
-# TODO, define iterable sources.  For now, we'll just use vocabularies.
-# Eventually, we'll replace vocabularies with iterable sources.
-    
 class IBaseVocabulary(ISource):
     """Representation of a vocabulary.
 
@@ -518,6 +534,21 @@ class IBaseVocabulary(ISource):
         If 'value' is not a valid term, this method raises LookupError.
         """
 
+
+class IIterableSource(ISource):
+    """Source which supports iteration over allowed values.
+
+    The objects iteration provides must be values from the source.
+    """
+
+    def __iter__():
+        """Return an iterator which provides the values from the source."""
+
+    def __len__():
+        """Return the number of valid values, or sys.maxint."""
+
+
+# BBB vocabularies are pending deprecation, hopefully in 3.3
 class IIterableVocabulary(Interface):
     """Vocabulary which supports iteration over allowed values.
 
@@ -561,3 +592,10 @@ class IVocabularyRegistry(Interface):
 
         When the vocabulary cannot be found, LookupError is raised.
         """
+
+class IVocabularyFactory(Interface):
+    """Can create vocabularies."""
+
+    def __call__(self, context):
+        """The context provides a location that the vocabulary can make use
+        of."""
