@@ -13,7 +13,17 @@
 ##############################################################################
 """Browser Simulator for Functional DocTests
 
-$Id: __init__.py 41261 2006-01-11 00:48:30Z jinty $
+$Id: __init__.py 41678 2006-02-18 20:59:24Z benji_york $
 """
 
-from testing import Browser
+try:
+    from testing import Browser
+    from zope.deprecation import deprecated
+    deprecated('Browser',
+        'importing Browser from zope.testbrowser has been deprecated and will'
+        ' be removed in 3.5; import Browser from zope.testbrowser.testing'
+        ' instead')
+except ImportError:
+    # This is really ugly, but non-Zope code needs to be able to import this
+    # and the testing module depends on Zope 3
+    pass
