@@ -13,7 +13,7 @@
 ##############################################################################
 """Mechanize-based Functional Doctest interfaces
 
-$Id: browser.py 69729 2006-08-22 17:51:38Z ctheune $
+$Id: browser.py 71525 2006-12-11 16:56:53Z poster $
 """
 __docformat__ = "reStructuredText"
 from test import pystone
@@ -362,9 +362,14 @@ class Browser(SetattrErrorsMixin):
         return Form(self, form)
 
     def _clickSubmit(self, form, control, coord):
+        labels = control.get_labels()
+        if labels:
+            label = labels[0].text
+        else:
+            label = None
         self._start_timer()
         self.mech_browser.open(form.click(
-                    id=control.id, name=control.name, coord=coord))
+            id=control.id, name=control.name, label=label, coord=coord))
         self._stop_timer()
 
     def _changed(self):
