@@ -13,18 +13,5 @@
 ##############################################################################
 """Set up testing environment
 
-$Id: __init__.py 26567 2004-07-16 06:58:27Z srichter $
+$Id: __init__.py 65557 2006-02-28 00:34:34Z nathan $
 """
-import os
-
-def patchTracebackModule():
-    """Use the ExceptionFormatter to show more info in tracebacks.
-    """
-    from zope.exceptions.exceptionformatter import format_exception
-    import traceback
-    traceback.format_exception = format_exception
-
-# Don't use the new exception formatter by default, since it
-# doesn't show filenames.
-if os.environ.get('NEW_ZOPE_EXCEPTION_FORMATTER', 0):
-    patchTracebackModule()
