@@ -13,18 +13,20 @@
 ##############################################################################
 """Tests for the testing framework.
 
-$Id: tests.py 28729 2005-01-05 15:42:08Z fdrake $
+$Id: tests.py 30492 2005-05-24 20:28:53Z jim $
 """
+import os
+import sys
 import unittest
-from zope.testing.doctestunit import DocTestSuite, DocFileSuite
-
+from zope.testing import doctest, testrunner
 
 def test_suite():
     return unittest.TestSuite((
-        DocFileSuite('formparser.txt'),
-        DocTestSuite('zope.testing.loggingsupport'),
+        doctest.DocTestSuite('zope.testing.renormalizing'),
+        doctest.DocFileSuite('formparser.txt'),
+        doctest.DocTestSuite('zope.testing.loggingsupport'),
+        testrunner.test_suite(),
         ))
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
-
