@@ -20,33 +20,38 @@ run from an installation.
 
 $Id$
 """
-
-import logging, os, sys, warnings
+import sys, os, warnings, logging
 from distutils.util import get_platform
 
-
-here = os.path.abspath(os.path.dirname(sys.argv[0]))
-
+# Insert build path
+PLAT_SPEC = "%s-%s" % (get_platform(), sys.version[0:3])
+here = os.path.dirname(os.path.realpath(__file__))
+lib = os.path.join(here, "build", "lib." + PLAT_SPEC)
+sys.path.insert(0, lib)
 # Remove this directory from path:
+here = os.path.abspath(os.path.dirname(sys.argv[0]))
 sys.path[:] = [p for p in sys.path if os.path.abspath(p) != here]
 
-# add build dir to path
-PLAT_SPEC = "%s-%s" % (get_platform(), sys.version[0:3])
-src = os.path.join(here, "build", "lib." + PLAT_SPEC)
-sys.path.insert(0, src) # put at beginning to avoid one in site_packages
-
 from zope.testing import testrunner
 
-defaults = ['--tests-pattern', '^f?tests$', '--test-path', src, '--all', '-u']
-
 # Get rid of twisted.conch.ssh warning
 warnings.filterwarnings(
     'ignore', 'PyCrypto', RuntimeWarning, 'twisted[.]conch[.]ssh')
 
-result = testrunner.run(defaults)
+defaultargs = ['--tests-pattern', '^f?tests$', '--test-path', lib,
+               '--unit', '--verbose']
+result = testrunner.run(defaultargs)
+
+# Note, the logging system has bugs, fixed in Python 2.5 that cause spurious
+# errors on exit.  We'll execute a fairly voilent suicide to try to avoid
+# these.  Given that this is just a test runner, this should be OK.
 
 # Avoid spurious error during exit. Some thing is trying to log
 # something after the files used by the logger have been closed.
 logging.disable(999999999)
 
-sys.exit(result)
+# Because we're about to use os._exit, we flush output so we don't miss any.
+sys.stdout.flush()
+sys.stderr.flush()
+
+os._exit(result)
